@@ -5,3 +5,5 @@ from ._private._elements import \
     EventSource, EventAnalyzer, EventSink, \
     TriggererEventSource, TriggerableEventSource, TriggerableEventBatchSource
 from ._private._pipeline import Pipeline
+from ._private._data_types import Server
+from ._private._common import PipelineException
